@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-toolbar-editor.c,v 1.14 2004/02/19 00:30:42 chpe Exp $
+ *  $Id: egg-toolbar-editor.c,v 1.15 2004/03/08 23:43:31 chpe Exp $
  */
 
 #include "egg-toolbar-editor.h"
@@ -306,11 +306,18 @@ editor_drag_data_received_cb (GtkWidget          *widget,
 			      EggToolbarEditor *editor)
 {
   GtkAction *action;
+  const char *data;
 
   g_return_if_fail (EGG_IS_TOOLBAR_EDITOR (editor));
   g_return_if_fail (selection_data != NULL);
 
-  action = find_action (editor, (const char *)selection_data->data);
+  if (selection_data->length <= 0 || selection_data->data == NULL) return;
+
+  data = (const char *) selection_data->data;
+
+  if (strcmp (data, "separator") == 0) return;
+
+  action = find_action (editor, data);
   g_return_if_fail (action != NULL);
 
   if (g_list_find (editor->priv->default_actions_list, action))
