@@ -18,13 +18,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c,v 1.36 2004/01/22 19:23:05 clahey Exp $
+ *  $Id: ephy-location-entry.c,v 1.41 2004/02/28 00:45:05 marco Exp $
  */
 
 #include "ephy-tree-model-node.h"
 #include "ephy-location-entry.h"
 #include "ephy-marshal.h"
 #include "ephy-debug.h"
+#include "egg-editable-toolbar.h"
 
 #include <gtk/gtktoolbar.h>
 #include <gtk/gtkentry.h>
@@ -192,6 +193,39 @@ entry_button_press_cb (GtkWidget *entry, GdkEventButton *event, EphyLocationEntr
 	return FALSE;
 }
 
+static gboolean
+keyword_match (const char *list,
+	       const char *keyword)
+{
+	const char *p;
+	gsize keyword_len;
+
+	p = list;
+	keyword_len = strlen (keyword);
+
+	while (*p)
+	{
+		int i;
+
+		for (i = 0; i < keyword_len; i++)
+		{
+			if (p[i] != keyword[i])
+			{
+				goto next_token;
+			}
+		}
+	  
+		return TRUE;
+	  
+		next_token:
+
+		while (*p && *p != ' ') p++;
+		if (*p) p++;
+	}
+
+	return FALSE;
+}
+
 static gboolean
 completion_func (GtkEntryCompletion *completion,
                  const char *key,
@@ -201,8 +235,6 @@ completion_func (GtkEntryCompletion *completion,
 	int i;
 	char *item = NULL;
 	char *keywords = NULL;
-	char *normalized_string, *normalized_keywords;
-	char *case_normalized_string, *case_normalized_keywords;
 	gboolean ret = FALSE;
 	EphyLocationEntry *le = EPHY_LOCATION_ENTRY (data);
 	GtkTreeModel *model;
@@ -210,20 +242,15 @@ completion_func (GtkEntryCompletion *completion,
 	model = gtk_entry_completion_get_model (completion);
 
 	gtk_tree_model_get (model, iter,
-			    le->priv->text_col, &item, -1);
-	gtk_tree_model_get (model, iter,
-			    le->priv->keywords_col, &keywords, -1);
+			    le->priv->text_col, &item,
+			    le->priv->keywords_col, &keywords,
+			    -1);
 
-	normalized_string = g_utf8_normalize (item, -1, G_NORMALIZE_ALL);
-	case_normalized_string = g_utf8_casefold (normalized_string, -1);
-	normalized_keywords = g_utf8_normalize (keywords, -1, G_NORMALIZE_ALL);
-	case_normalized_keywords = g_utf8_casefold (normalized_keywords, -1);
-
-	if (!strncmp (key, case_normalized_string, strlen (key)))
+	if (!strncmp (key, item, strlen (key)))
 	{
 		ret = TRUE;
 	}
-	else if (strstr (case_normalized_keywords, key))
+	else if (keyword_match (keywords, key))
 	{
 		ret = TRUE;
 	}
@@ -235,8 +262,7 @@ completion_func (GtkEntryCompletion *completion,
 
 			key_prefixed = g_strconcat (web_prefixes[i], key, NULL);
 
-			if (!strncmp (key_prefixed, case_normalized_string,
-				      strlen (key_prefixed)))
+			if (!strncmp (key_prefixed, item, strlen (key_prefixed)))
 			{
 				g_free (key_prefixed);
 
@@ -249,11 +275,7 @@ completion_func (GtkEntryCompletion *completion,
 	}
 
 	g_free (item);
-	g_free (normalized_string);
-	g_free (case_normalized_string);
 	g_free (keywords);
-	g_free (normalized_keywords);
-	g_free (case_normalized_keywords);
 
 	return ret;
 }
@@ -277,6 +299,52 @@ match_selected_cb (GtkEntryCompletion *completion,
 	return TRUE;
 }
 
+static gboolean
+toolbar_is_editable (GtkWidget *widget)
+{
+	GtkWidget *etoolbar;
+
+	etoolbar = gtk_widget_get_ancestor (widget, EGG_TYPE_EDITABLE_TOOLBAR);
+
+	if (etoolbar)
+	{
+		return egg_editable_toolbar_get_edit_mode
+			(EGG_EDITABLE_TOOLBAR (etoolbar));
+	}
+
+	return FALSE;
+}
+
+static gboolean
+entry_drag_motion_cb (GtkWidget        *widget,
+		      GdkDragContext   *context,
+		      gint              x,
+		      gint              y,
+		      guint             time)
+{
+	if (toolbar_is_editable (widget))
+	{
+		g_signal_stop_emission_by_name (widget, "drag_motion");
+	}
+    
+	return FALSE;
+}
+
+static gboolean
+entry_drag_drop_cb (GtkWidget          *widget,
+		    GdkDragContext     *context,
+		    gint                x,
+		    gint                y,
+		    guint               time)
+{
+	if (toolbar_is_editable (widget))
+	{
+		g_signal_stop_emission_by_name (widget, "drag_drop");
+	}
+
+	return FALSE;
+}
+
 static void
 ephy_location_entry_construct_contents (EphyLocationEntry *le)
 {
@@ -285,6 +353,7 @@ ephy_location_entry_construct_contents (EphyLocationEntry *le)
 	LOG ("EphyLocationEntry constructing contents %p", le)
 
 	p->entry = gtk_entry_new ();
+	
 	gtk_container_add (GTK_CONTAINER (le), p->entry);
 	gtk_widget_show (p->entry);
 
@@ -292,6 +361,10 @@ ephy_location_entry_construct_contents (EphyLocationEntry *le)
 			  G_CALLBACK (entry_button_press_cb), le);
 	g_signal_connect (p->entry, "changed",
 			  G_CALLBACK (editable_changed_cb), le);
+	g_signal_connect (p->entry, "drag_motion",
+			  G_CALLBACK (entry_drag_motion_cb), le);
+	g_signal_connect (p->entry, "drag_drop",
+			  G_CALLBACK (entry_drag_drop_cb), le);
 }
 
 static void
