@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extension.c,v 1.1 2003/11/10 21:36:31 chpe Exp $
+ *  $Id: ephy-extension.c,v 1.3 2004/02/17 12:03:25 chpe Exp $
  */
 
 #include "ephy-extension.h"
@@ -30,15 +30,14 @@ ephy_extension_get_type (void)
 	{
 		static const GTypeInfo our_info =
 		{
-			sizeof (EphyExtensionClass),
+			sizeof (EphyExtensionIface),
 			NULL,
 			NULL,
 		};
 	
 		type = g_type_register_static (G_TYPE_INTERFACE,
 					       "EphyExtension",
-					       &our_info,
-					       G_TYPE_FLAG_ABSTRACT);
+					       &our_info, 0);
 	}
 
 	return type;
@@ -48,14 +47,14 @@ void
 ephy_extension_attach_window (EphyExtension *extension,
 			      EphyWindow *window)
 {
-	EphyExtensionClass *class = EPHY_EXTENSION_GET_CLASS (extension);
-	class->attach_window (extension, window);
+	EphyExtensionIface *iface = EPHY_EXTENSION_GET_IFACE (extension);
+	iface->attach_window (extension, window);
 }
 
 void
 ephy_extension_detach_window (EphyExtension *extension,
 			      EphyWindow *window)
 {
-	EphyExtensionClass *class = EPHY_EXTENSION_GET_CLASS (extension);
-	class->detach_window (extension, window);
+	EphyExtensionIface *iface = EPHY_EXTENSION_GET_IFACE (extension);
+	iface->detach_window (extension, window);
 }
