@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.110 2004/01/25 20:10:07 chpe Exp $
+ *  $Id: window-commands.c,v 1.115 2004/03/04 19:32:29 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -362,23 +362,26 @@ window_cmd_file_bookmark_page (GtkAction *action,
 }
 
 static void
-open_response_cb (GtkDialog *dialog, gint response, EphyWindow *window)
+open_response_cb (GtkDialog *dialog, int response, EphyWindow *window)
 {
 	if (response == EPHY_RESPONSE_OPEN)
 	{
 		char *uri, *converted;
 
 		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog));
-		converted = g_filename_to_utf8 (uri, -1, NULL, NULL, NULL);
-
-		if (converted != NULL)
+		if (uri != NULL)
 		{
-			ephy_window_load_url(window, converted);
-		}
-
-		g_free (converted);
-		g_free (uri);
-        }
+			converted = g_filename_to_utf8 (uri, -1, NULL, NULL, NULL);
+	
+			if (converted != NULL)
+			{
+				ephy_window_load_url (window, converted);
+			}
+	
+			g_free (converted);
+			g_free (uri);
+	        }
+	}
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
@@ -738,7 +741,6 @@ save_temp_source (EphyEmbed *embed)
 {
 	char *tmp, *base;
 	EphyEmbedPersist *persist;
-
 	const char *static_temp_dir;
 
 	static_temp_dir = ephy_file_tmp_dir ();
@@ -928,7 +930,6 @@ window_cmd_help_about (GtkAction *action,
 {
 	static GtkWidget *about = NULL;
 	GtkWidget** ptr;
-	GdkPixbuf *icon;
 	const char *icon_path;
 	GdkPixbuf *logo = NULL;
 	GtkIconTheme *icon_theme;
@@ -950,7 +951,7 @@ window_cmd_help_about (GtkAction *action,
 	};
 
 	/* Translator credits */
-	char *translator_credits = _("translator_credits");
+	char *translator_credits = _("translator-credits");
 
 	if (about != NULL)
 	{
@@ -983,7 +984,7 @@ window_cmd_help_about (GtkAction *action,
 		       _("A GNOME browser based on Mozilla"),
 		       (const char **)authors,
 		       (const char **)documenters,
-		       strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		       strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 		       logo);
 
 	if (logo != NULL)
@@ -994,13 +995,6 @@ window_cmd_help_about (GtkAction *action,
 	gtk_window_set_transient_for (GTK_WINDOW (about),
 				      GTK_WINDOW (window));
 
-	icon = gtk_widget_render_icon (about,
-				       GNOME_STOCK_ABOUT,
-				       GTK_ICON_SIZE_MENU,
-				       NULL);
-	gtk_window_set_icon (GTK_WINDOW (about), icon);
-	g_object_unref(icon);
-
 	ptr = &about;
 	g_object_add_weak_pointer (G_OBJECT (about), (gpointer *)ptr);
 	gtk_widget_show (about);
@@ -1059,7 +1053,8 @@ window_cmd_tabs_move_left  (GtkAction *action,
 		GtkWidget *child;
 
 		child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page);
-		ephy_notebook_move_page (EPHY_NOTEBOOK (notebook), NULL, child, page - 1);
+		ephy_notebook_move_tab (EPHY_NOTEBOOK (notebook), NULL,
+					EPHY_TAB (child), page - 1);
 	}
 }
 
@@ -1079,7 +1074,8 @@ void window_cmd_tabs_move_right (GtkAction *action,
 		GtkWidget *child;
 
 		child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page);
-		ephy_notebook_move_page (EPHY_NOTEBOOK (notebook), NULL, child, page + 1);
+		ephy_notebook_move_tab (EPHY_NOTEBOOK (notebook), NULL,
+					EPHY_TAB (child), page + 1);
 	}
 }
 
@@ -1088,19 +1084,18 @@ window_cmd_tabs_detach  (GtkAction *action,
 			 EphyWindow *window)
 {
 	EphyTab *tab;
-	GtkWidget *src_page, *nb;
+	GtkWidget *nb;
 	EphyWindow *new_win;
 
 	nb = ephy_window_get_notebook (window);
 	if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) <= 1) return;
 
 	tab = ephy_window_get_active_tab (window);
-	src_page = GTK_WIDGET (ephy_tab_get_embed (tab));
+
 	new_win = ephy_window_new ();
-	ephy_notebook_move_page (EPHY_NOTEBOOK (ephy_window_get_notebook (window)),
+	ephy_notebook_move_tab (EPHY_NOTEBOOK (ephy_window_get_notebook (window)),
 				EPHY_NOTEBOOK (ephy_window_get_notebook (new_win)),
-				src_page, 0);
-	ephy_tab_set_window (tab, new_win);
+				tab, 0);
 	gtk_widget_show (GTK_WIDGET (new_win));
 }
 
